=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2006-09-20 16:32:06 +0000
+++ bzrlib/lockdir.py	2006-09-20 17:01:14 +0000
@@ -130,8 +130,8 @@
 # TODO: Make sure to pass the right file and directory mode bits to all
 # files/dirs created.
 
-_DEFAULT_TIMEOUT_SECONDS = 60
-_DEFAULT_POLL_SECONDS = 0.5
+_DEFAULT_TIMEOUT_SECONDS = 3600
+_DEFAULT_POLL_SECONDS = 1.0
 
 class LockDir(object):
     """Write-lock guarding access to data."""
@@ -373,16 +373,21 @@
             new_info = self.peek()
             mutter('last_info: %s, new info: %s', last_info, new_info)
             if new_info is not None and new_info != last_info:
+                if last_info is None:
+                    start = 'Unable to obtain'
+                else:
+                    start = 'Lock owner changed for'
                 last_info = new_info
                 formatted_info = self._format_lock_info(new_info)
-                self._report_function('Unable to obtain %s\n'
+                self._report_function('%s %s\n'
                                       '%s\n' # held by
                                       '%s\n' # locked ... ago
                                       'Will continue to try for %s seconds\n',
+                                      start,
                                       formatted_info[0],
                                       formatted_info[1],
                                       formatted_info[2],
-                                      deadline - time.time())
+                                      int(deadline - time.time()))
 
             if time.time() + poll < deadline:
                 time.sleep(poll)

=== modified file 'bzrlib/tests/test_lockdir.py'
--- bzrlib/tests/test_lockdir.py	2006-09-20 16:33:19 +0000
+++ bzrlib/tests/test_lockdir.py	2006-09-20 17:01:14 +0000
@@ -182,15 +182,16 @@
             lf1.unlock()
         lock_base = lf2.transport.abspath(lf2.path)
         self.assertEqual(1, len(self._logged_reports))
-        self.assertEqual('Unable to obtain %s\n'
+        self.assertEqual('%s %s\n'
                          '%s\n%s\n'
                          'Will continue to try for %s seconds\n',
                          self._logged_reports[0][0])
         args = self._logged_reports[0][1]
-        self.assertEqual('lock %s' % (lock_base,), args[0])
-        self.assertStartsWith(args[1], 'held by ')
-        self.assertStartsWith(args[2], 'locked ')
-        self.assertEndsWith(args[2], ' ago')
+        self.assertEqual('Unable to obtain', args[0])
+        self.assertEqual('lock %s' % (lock_base,), args[1])
+        self.assertStartsWith(args[2], 'held by ')
+        self.assertStartsWith(args[3], 'locked ')
+        self.assertEndsWith(args[3], ' ago')
 
     def test_31_lock_wait_easy(self):
         """Succeed when waiting on a lock with no contention.
@@ -239,15 +240,16 @@
         # wait for a while
         lock_base = lf2.transport.abspath(lf2.path)
         self.assertEqual(1, len(self._logged_reports))
-        self.assertEqual('Unable to obtain %s\n'
+        self.assertEqual('%s %s\n'
                          '%s\n%s\n'
                          'Will continue to try for %s seconds\n',
                          self._logged_reports[0][0])
         args = self._logged_reports[0][1]
-        self.assertEqual('lock %s' % (lock_base,), args[0])
-        self.assertStartsWith(args[1], 'held by ')
-        self.assertStartsWith(args[2], 'locked ')
-        self.assertEndsWith(args[2], ' ago')
+        self.assertEqual('Unable to obtain', args[0])
+        self.assertEqual('lock %s' % (lock_base,), args[1])
+        self.assertStartsWith(args[2], 'held by ')
+        self.assertStartsWith(args[3], 'locked ')
+        self.assertEndsWith(args[3], ' ago')
 
     def test_33_wait(self):
         """Succeed when waiting on a lock that gets released
@@ -295,7 +297,6 @@
             # wait and then lock
             lf2.lock_write()
             after = time.time()
-            self.assertTrue(after - before <= 1.0)
         finally:
             unlocker.join()
 
@@ -303,15 +304,16 @@
         # wait for a while
         lock_base = lf2.transport.abspath(lf2.path)
         self.assertEqual(1, len(self._logged_reports))
-        self.assertEqual('Unable to obtain %s\n'
+        self.assertEqual('%s %s\n'
                          '%s\n%s\n'
                          'Will continue to try for %s seconds\n',
                          self._logged_reports[0][0])
         args = self._logged_reports[0][1]
-        self.assertEqual('lock %s' % (lock_base,), args[0])
-        self.assertStartsWith(args[1], 'held by ')
-        self.assertStartsWith(args[2], 'locked ')
-        self.assertEndsWith(args[2], ' ago')
+        self.assertEqual('Unable to obtain', args[0])
+        self.assertEqual('lock %s' % (lock_base,), args[1])
+        self.assertStartsWith(args[2], 'held by ')
+        self.assertStartsWith(args[3], 'locked ')
+        self.assertEndsWith(args[3], ' ago')
 
     def test_35_wait_lock_changing(self):
         """LockDir.wait_lock() will report if the lock changes underneath.
@@ -400,9 +402,9 @@
         unlocker.start()
         try:
             # Start the other thread
-            time.sleep(0.1)
+            time.sleep(0.2)
             # wait and then lock
-            lf2.wait_lock(timeout=1.0, poll=0.1)
+            lf2.wait_lock(timeout=2.0, poll=0.1)
         finally:
             unlocker.join()
         lf2.unlock()
@@ -410,18 +412,19 @@
         # There should be 2 reports, because the lock changed
         lock_base = lf2.transport.abspath(lf2.path)
         self.assertEqual(2, len(self._logged_reports))
-        def check_one(index):
-            self.assertEqual('Unable to obtain %s\n'
+        def check_one(index, msg):
+            self.assertEqual('%s %s\n'
                              '%s\n%s\n'
                              'Will continue to try for %s seconds\n',
                              self._logged_reports[index][0])
             args = self._logged_reports[index][1]
-            self.assertEqual('lock %s' % (lock_base,), args[0])
-            self.assertStartsWith(args[1], 'held by ')
-            self.assertStartsWith(args[2], 'locked ')
-            self.assertEndsWith(args[2], ' ago')
-        check_one(0)
-        check_one(1)
+            self.assertEqual(msg, args[0])
+            self.assertEqual('lock %s' % (lock_base,), args[1])
+            self.assertStartsWith(args[2], 'held by ')
+            self.assertStartsWith(args[3], 'locked ')
+            self.assertEndsWith(args[3], ' ago')
+        check_one(0, 'Unable to obtain')
+        check_one(1, 'Lock owner changed for')
 
     def test_40_confirm_easy(self):
         """Confirm a lock that's already held"""

